@@ -34,11 +34,6 @@
 //! Complete examples showing how to use the library can be found
 //! [here](https://github.com/dimbleby/rust-c-ares/tree/master/examples).
 #![deny(missing_docs)]
-#[macro_use]
-extern crate bitflags;
-extern crate c_ares_sys;
-extern crate c_types;
-extern crate itertools;
 
 #[macro_use]
 mod macros;
